@@ -5,7 +5,7 @@ use warnings;
 use base qw( Alien::Base );
 
 # ABSTRACT: Find or build nettle low-level cryptographic library
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 
 
@@ -27,48 +27,45 @@ Alien::Nettle - Find or build nettle low-level cryptographic library
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
+In your Makefile.PL:
+
+ use ExtUtils::MakeMaker;
+ use Alien::Base::Wrapper ();
+
+ WriteMakefile(
+   Alien::Base::Wrapper->new('Alien::Nettle')->mm_args2(
+     # MakeMaker args
+     NAME => 'My::XS',
+     ...
+   ),
+ );
+
 In your Build.PL:
 
  use Module::Build;
- use Alien::Nettle;
+ use Alien::Base::Wrapper qw( Alien::Nettle !export );
+
  my $builder = Module::Build->new(
    ...
    configure_requires => {
      'Alien::Nettle' => '0',
      ...
    },
-   extra_compiler_flags => Alien::Nettle->cflags,
-   extra_linker_flags   => Alien::Nettle->libs,
+   Alien::Base::Wrapper->mb_args,
    ...
  );
- 
+
  $build->create_build_script;
 
-In your Makefile.PL:
-
- use ExtUtils::MakeMaker;
- use Config;
- use Alien::Nettle;
- 
- WriteMakefile(
-   ...
-   CONFIGURE_REQUIRES => {
-     'Alien::Nettle' => '0',
-   },
-   CCFLAGS => Alien::Nettle->cflags . " $Config{ccflags}",
-   LIBS    => [ Alien::Nettle->libs ],
-   ...
- );
-
 =head1 DESCRIPTION
 
-This distribution provides Nettle so that it can be used by other 
-Perl distributions that are on CPAN.  It does this by first trying to 
-detect an existing install of Nettle on your system.  If found it 
+This distribution provides Nettle so that it can be used by other
+Perl distributions that are on CPAN.  It does this by first trying to
+detect an existing install of Nettle on your system.  If found it
 will use that.  If it cannot be found, the source code will be downloaded
 from the internet and it will be installed in a private share location
 for the use of other modules.
